# Copyright (c) 2014 VMware, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_vmware._i18n import _


class Datacenter(object):

    def __init__(self, ref, name):
        """Datacenter object holds ref and name together for convenience."""
        if name is None:
            raise ValueError(_("Datacenter name cannot be None"))
        if ref is None:
            raise ValueError(_("Datacenter reference cannot be None"))
        self.ref = ref
        self.name = name
